function logl=lkhd_object(female,coefs,obs_1,obs_2,obs_3,obs_4,p_childMat)
%store each trial coefs

global store_coef;
store_coef=[store_coef; coefs];

%**LIST OF PARAMETERS**********
h1=30;
h2=40;
Gamma=0.90;

%****scale preference parameters
scalar=[10	10	10	100	10	0.01	10	10	10	0.1	0.1	10	1	100	10	10	0.1	0.1	0.1	10^4 10 100];
coefs=coefs./scalar;

v_a0=coefs(1);

p_n=coefs(3);

v_e=coefs(5); %variance of measurement error
alpha2=coefs(6);
xiMat=coefs(7:8);
p_xi2=coefs(9);
alpha1=coefs(10);  %this is the constant term (base group)
utype2=coefs(11); %utype2 relative to utype1=0
p_type2=coefs(12); %prob of second type
%wage coefs
beta=coefs(13:16)'; %constant, urate,white,metro 
%preference coefs: note there is no intercept here--we allow for two
%type-specifc intercepts 
theta=coefs(17:19)'; %white, married, children
%***************
bc=theta(end); %preference for children
xiGrids=length(xiMat);
utype=[alpha1 alpha1+utype2];
p_xi=[1-p_xi2, p_xi2];
p_u0=[1-p_type2, p_type2];

s_a0=sqrt(v_a0);
s_e=sqrt(v_e);
%*********************************************************

rand('seed',1) 
%*****MODEL SETUP****
maxchild=2;
aGrids=10;
aSmall=-10;
aHuge=10;
% auxiliary variables for solving value function
convergence_criterion = 0.5;
maxIter = 1000;
metric = 1;
%scalar to smooth likelihood function 
cc=0.01;
%number of simulated history draws in likelihood function
S=5;
%********************

%grid points for a
aMat     = DiscreteApproxToNormal(s_a0,0, aGrids-2);
aMat = [aSmall; aMat; aHuge];
%grid points for permanent unobserved heterogeneity
max_type_i=length(utype);

%solve value function for all observed X's and permanent unobserved
%heterogeneity
counter=1;
type=zeros(2^4,4);
for married=0:1
            for urate=0:1
                for white=0:1
                    for metro=0:1
                    type(counter,:)=[married, urate, white, metro]; 
                    counter=counter+1;
                    end
                end
            end
end

%iteration 0: initial guess of the value function at all points in the state space; 
v_alpha=ones(maxchild+1,max_type_i,length(type))*1000;
vnext_a0=ones(aGrids,xiGrids, maxchild+1,max_type_i, length(type))*1000;
v_h1=zeros(aGrids,xiGrids, maxchild+1,max_type_i, length(type));
v_h2=zeros(aGrids,xiGrids, maxchild+1,max_type_i, length(type));
counter = 1;
while metric > convergence_criterion;   
    %RECORD ITERATION FROM LAST PERIOD
    v_alpha_last=v_alpha;
    vnext_a0_last=vnext_a0;
    %built parfor loop in to increase speed
    parfor kk=1:length(type)
    X=type(kk,:);
    p_child=p_childMat(kk,1);
    v_alpha_last_kk=v_alpha_last(:,:,kk);
    vnext_a0_last_kk=vnext_a0_last(:,:,:,:,kk);
    [v_alpha(:,:,kk), vnext_a0(:,:,:,:,kk), v_h1(:,:,:,:,kk), v_h2(:,:,:,:,kk)]...
        = apprValueFunction(female,Gamma, aMat,maxchild,coefs, X, p_child, v_alpha_last_kk, vnext_a0_last_kk);
    end
    counter = counter+1;
    if counter > maxIter;
        'Iterations exceed MaxIter'
    break;
    else
    v1=abs(v_alpha-v_alpha_last);
    v2=abs(vnext_a0_last-vnext_a0);
    diff1=sort(v1(:));
    diff2=sort(v2(:));
    %maximum difference over all state space
    metric = max(diff1(end), diff2(end));
    end      
end

[abar_1_all, astar_all, a_r_all ]=reservation(aMat,xiMat,maxchild,length(type), max_type_i,v_h1, v_h2, v_alpha, vnext_a0,cc);

l1=zeros(size(obs_1,1),1);
l2=zeros(size(obs_2,1),1);
l3=zeros(size(obs_3,1),1);
l4=zeros(size(obs_4,1),1);

%type 4 likelihood
parfor i=1:size(obs_4,1)
    d=obs_4(i,1);
    X=obs_4(i,2:end);
    dspell=X(6); 
    childvec=X(7:end-1)+1;
    ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);
        abar1_i=abar_1_all(:,:,:,temp);
        l4(i) =    loglkhd4(d,xiGrids,p_xi,p_n,s_a0,abar1_i,dspell, childvec,max_type_i,p_u0);
end

%Type 1 likelihood
parfor i=1:size(obs_1,1)
    d=obs_1(i,1);
    T1=obs_1(i,2);
    w1=obs_1(i,3);
    H1=obs_1(i,4);
    w2=obs_1(i,5);
    H2=obs_1(i,6);
    X=obs_1(i,7:end);
    jspell=X(1);
    dspell=X(6); 
    childvec=X(7:end-1)+1;    
    person=X(end);
    rand('seed',person) %fix the person specific draws 
    X_w=[1, X(3),X(4), X(5)]; 
    ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);    
    lw0_p=X_w*beta;    
            abar1_i=abar_1_all(:,:,:,temp);
            astar_i=astar_all(:,:,:,temp);
            a_r_i=a_r_all(:,:,:,:,:, temp);
    l1(i)= loglkhd1(female,d,T1,w1,w2,H1,H2,lw0_p,coefs,abar1_i,astar_i,a_r_i,aMat,S,...
            jspell, dspell,childvec,cc);
    if l1(i)==0
        l1(i)=1e-200;
    end
end

%Type 2 likelihood
parfor i=1:size(obs_2,1)
    d=obs_2(i,1);
    T1=obs_2(i,2);
    w1=obs_2(i,3);
    H1=obs_2(i,4);
    X=obs_2(i,5:end);
    jspell=X(1);
    dspell=X(6); 
    childvec=X(7:end-1)+1;
    person=X(end);
    rand('seed',person) %fix the person specific draws 
    X_w=[1, X(3),X(4), X(5)]; 
    ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);    
    lw0_p=X_w*beta;    
            abar1_i=abar_1_all(:,:,:,temp);
            astar_i=astar_all(:,:,:,temp);
            a_r_i=a_r_all(:,:,:,:,:, temp);
    l2(i)= loglkhd2(female,d,T1,w1,H1,lw0_p,coefs,abar1_i,astar_i,a_r_i,aMat,S,...
            jspell, dspell,childvec,cc);
    if l2(i)==0
        l2(i)=1e-200;
    end
end

%Type 3 likelihood
parfor i=1:size(obs_3,1)
    d=obs_3(i,1);
    T1=obs_3(i,2);
    w1=obs_3(i,3);
    H1=obs_3(i,4);
    X=obs_3(i,5:end);
    jspell=X(1);
    dspell=X(6); 
    childvec=X(7:end-1)+1;
    person=X(end);
    rand('seed',person) %fix the person specific draws 
    X_w=[1, X(3),X(4), X(5)];  
    ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);    
    lw0_p=X_w*beta;    
            abar1_i=abar_1_all(:,:,:,temp);
            astar_i=astar_all(:,:,:,temp);
            a_r_i=a_r_all(:,:,:,:,:, temp);
    l3(i)= loglkhd3(female,d,T1,w1,H1,lw0_p,coefs,abar1_i,astar_i,a_r_i,aMat,S,...
            jspell, dspell,childvec,cc);
    if l3(i)==0
        l3(i)=1e-200;
    end
end

%log likelihood
logl=-(sum(log(l1))+sum(log(l2))+sum(log(l3))+sum(log(l4)));

return