
%{
   ***************************************************************
   ***************************************************************
   ***************************************************************
   ** MAX_BHHH Function -- Maximum likelihood estimation (BHHH) **
   ***************************************************************
%}
function [betas, cov_betas, llf_vec] = max_bhhh(female,b0, obs_1,obs_2,obs_3,obs_4,p_childMat, names)
   global numobs iter_limit critic_limit do_step H;
   crit = 1;              % Initialize critical value of % beta change
   iter = 1;              % Initialize iteration count
   s = 1;                 % Initialize step length
   disp('Below is the intermediate iteration information:');     
   disp('  ');
li(1)=sum(lkhd_object_bhhh(female,b0',obs_1,obs_2,obs_3,obs_4,p_childMat));
fprintf('Initial LLF = %8.4f\r', li(1)); % Print current LLF
                %******* Begin do loop *********
   while ((crit > critic_limit) & (iter<= iter_limit));                 
      z = Grad(female,b0,numobs,obs_1,obs_2,obs_3,obs_4,p_childMat);  % Numerical Gradients          
      H = z'*z;                       % Compute approx. to Hessian   
      g = sum(z)';                    % Gradient vector (K x 1)  
      db = inv(H)*g;                  % Compute full step adjustment 
      if do_step == 1;                % Use a variable step length 
       s = 1;                         % Reset base step length 
       li1 = 0; li2 = 1;              % ** Intialize LLF's under 2 step lengths
       while (li1 < li2) && (s >=.02); 
          li1 = sum(lkhd_object_bhhh(female,(b0 + s*db)',obs_1,obs_2,obs_3,obs_4,p_childMat));  %Eval. LLF at higher SL
          li2 = sum(lkhd_object_bhhh(female,(b0 + s*db/2)',obs_1,obs_2,obs_3,obs_4,p_childMat));%Eval. LLF at lower SL    
          s_star=s;
          s = s/2;
       end
      else
          s_star = s;
      end

      betas = b0 + s_star*db;               % Update parameter values            
       
      iter = iter + 1;               % Update iteration count
li(iter)=sum(lkhd_object_bhhh(female,betas',obs_1,obs_2,obs_3,obs_4,p_childMat));
fprintf('Current LLF = %8.4f\r', li(iter)); % Print current LLF
if li(iter)<li(iter-1)
    betas = b0;
break;
end
      crit = max(abs((betas-b0)./b0)./s_star); % Eval. size adjusted % parm change
      b0 = betas;                    % Replace old parm vector w/new
      disp('  ');
      disp('  ');
      fprintf('i = %3.0f\r', iter);    % Print iteration number
      fprintf('%8.4f',betas');       % Print out all paramatrs if less than 7
      disp('  ');

   end
   llf_vec=lkhd_object_bhhh(female,b0',obs_1,obs_2,obs_3,obs_4,p_childMat); % Vector of Log-Likelihood values
   cov_betas=inv(H);            % BHHH method for Param. Cov. calculation
   std = sqrt(diag(cov_betas)); % Compute estimated std. errors
   zvalue=betas./std;           % t-values 
   df= numobs-length(b0);              % Degrees of freedom for t-value
   pvalue=2*(1-normcdf(abs(zvalue)));  % Column vector of param p-values 
   disp('  ');
   disp('  ');
   disp('Final results:');
   results=horzcat(b0,std,zvalue,pvalue); % Build results matrix   
   table_bwg(names,results,9);
   disp('  ');
   
end
 
    
    

