function data_sim=model_fit(female,coefs,obs_1,obs_2,obs_3,obs_4,p_childMat)

rand('seed',1)

%**LIST OF PARAMETERS**********
h1=30;
h2=40;
Gamma=0.90;

scalar=[10	10	10	100	10	0.01	10	10	10	0.1	0.1	10	1	100	10	10	0.1	0.1	0.1	10^4 10 100];
coefs=coefs./scalar;

v_a0=coefs(1);

p_n=coefs(3);

v_e=coefs(5); %variance of measurement error
alpha2=coefs(6);
xiMat=coefs(7:8);
p_xi2=coefs(9);
%parameters of the types; in value function since they are given
alpha1=coefs(10);  %this is the constant term (base group)
utype2=coefs(11); %utype2 relative to utype1=0
p_type2=coefs(12); %prob of second type
%wage coefs
beta=coefs(13:16)'; %constant, urate,white,metro 
%preference coefs: note there is no intercept here--we allow for two
%type-specifc intercepts 
theta=coefs(17:19)'; %white, married, children
%***************
bc=theta(end); %preference for children
xiGrids=length(xiMat);
utype=[alpha1 alpha1+utype2];
p_xi=[1-p_xi2, p_xi2];
p_u0=[1-p_type2, p_type2];
s_a0=sqrt(v_a0);
s_e=sqrt(v_e);
%*********************************************************

%TimeS = cputime;

%*****MODEL SETUP****
maxchild=2;
aGrids=10;
aSmall=-10;
aHuge=10;
% auxiliary variables for solving value function
convergence_criterion = 0.5;
maxIter = 1000;
metric = 1;
%scalar to smooth likelihood function 
cc=0.01;
%number of simulated history draws in likelihood function
S=20;
%********************

%grid points for a
aMat     = DiscreteApproxToNormal(s_a0,0, aGrids-2);
aMat = [aSmall; aMat; aHuge];
%grid points for permanent unobserved heterogeneity
max_type_i=length(utype);

%solve value function for all observed X's and permanent unobserved
%heterogeneity
%observed permanent types: married, educ, urate, white, metro
counter=1;
type=zeros(2^4,4);
for married=0:1
            for urate=0:1
                for white=0:1
                    for metro=0:1
                    type(counter,:)=[married, urate, white, metro]; %first two element is married and child
                    counter=counter+1;
                    end
                end
            end
end

%iteration 0: initial guess of the value function at all points in the state space; 
v_alpha=ones(maxchild+1,max_type_i,length(type))*1000;
vnext_a0=ones(aGrids,xiGrids, maxchild+1,max_type_i, length(type))*1000;
v_h1=zeros(aGrids,xiGrids, maxchild+1,max_type_i, length(type));
v_h2=zeros(aGrids,xiGrids, maxchild+1,max_type_i, length(type));
counter = 1;
while metric > convergence_criterion;   
    %RECORD ITERATION FROM LAST PERIOD
    v_alpha_last=v_alpha;
    vnext_a0_last=vnext_a0;
    %built parfor loop in to increase speed
    parfor kk=1:length(type)
    X=type(kk,:);
    p_child=p_childMat(kk,1);
    v_alpha_last_kk=v_alpha_last(:,:,kk);
    vnext_a0_last_kk=vnext_a0_last(:,:,:,:,kk);
    [v_alpha(:,:,kk), vnext_a0(:,:,:,:,kk), v_h1(:,:,:,:,kk), v_h2(:,:,:,:,kk)]...
        = apprValueFunction(female,Gamma,aMat,maxchild,coefs, X, p_child, v_alpha_last_kk, vnext_a0_last_kk);
    end
    counter = counter+1;
    if counter > maxIter;
        'Iterations exceed MaxIter'
    break;
    else
    v1=abs(v_alpha-v_alpha_last);
    v2=abs(vnext_a0_last-vnext_a0);
    diff1=sort(v1(:));
    diff2=sort(v2(:));
    %maximum difference over all state space
    metric = max(diff1(end), diff2(end));
    end      
end

%cc enters in as argument to scale the extrapolation (otherwise reservation
%wage can be large and a2 draws are Inf)
[abar_1_all, astar_all, a_r_all ]=reservation(aMat,xiMat,maxchild,length(type), max_type_i,v_h1, v_h2, v_alpha, vnext_a0,cc);

%simulate histories for each type of worker from t=0 
S_sim=5000;
T_sim=80; %assume T_sim is at steady state
p_type2=coefs(12); %prob of second type
maxchild=2;
%simulate unobserved type at time 0, independently with observed type (and same
%simulated types for all xtypes
off2 = binornd(1,p_type2,S_sim,1);
type_i=off2+1; %unobserved preference: 2=high pref type; 1=low pref type
hist_sim=zeros(S_sim,9,maxchild+1, length(type));
u = rand(S_sim,1);
a_off = norminv(u,0,s_a0);
    
parfor type_count=1:length(type)  
    rand('seed',type_count)
        a_bar1=abar_1_all(:,:,:,type_count);
        astar=astar_all(:,:,:,type_count);
        a_r=a_r_all(:,:,:, :,:,type_count);
        [hist_sim(:,:,:,type_count)] =sim_history(S_sim,T_sim, maxchild,coefs, aMat, a_off, type(type_count,:), type_i, a_bar1, astar, a_r);
end

   
ind_vec=[];
for i=1:size(obs_1,1)
    d=obs_1(i,1);
    T1=obs_1(i,2);
    w1=obs_1(i,3);
    H1=obs_1(i,4);
    w2=obs_1(i,5);
    H2=obs_1(i,6);
    X=obs_1(i,7:end);
    jspell=X(1);
    dspell=X(6); 
    childvec=X(7:end-1)+1;    
    person=X(end);
    X_w=[1, X(3),X(4), X(5)]; 
   ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);    
    %number of children evaluated at the first interview
    child=childvec(1);
    ind_vec=[ind_vec; temp child person];
end

for i=1:size(obs_2,1)
    d=obs_2(i,1);
    T1=obs_2(i,2);
    w1=obs_2(i,3);
    H1=obs_2(i,4);
    X=obs_2(i,5:end);
    jspell=X(1);
    dspell=X(6); 
    childvec=X(7:end-1)+1;
    person=X(end);
    X_w=[1, X(3),X(4), X(5)]; 
   ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);  
        %number of children evaluated at the point where w1 is observed
    child=childvec(1);
    ind_vec=[ind_vec; temp child person];
end

%Type 3 likelihood
for i=1:size(obs_3,1)
    d=obs_3(i,1);
    T1=obs_3(i,2);
    w1=obs_3(i,3);
    H1=obs_3(i,4);
    X=obs_3(i,5:end);
    jspell=X(1);
    dspell=X(6); 
    childvec=X(7:end-1)+1;
    person=X(end);
    X_w=[1, X(3),X(4), X(5)];  
    ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);    
    %number of children evaluated at the point where w1 is observed
    child=childvec(1);
    ind_vec=[ind_vec; temp child person];
end
%
for i=1:size(obs_4,1)
    d=obs_4(i,1);
    X=obs_4(i,2:end);
    dspell=X(6); 
    childvec=X(7:end-1)+1;
person=X(end);
    ind=(type(:,1)==X(2)  & type(:,2)==X(3)  & type(:,3)==X(4) & type(:,4)==X(5) );
    temp=find(ind==1);
    %number of children evaluated at the point where w1 is observed
    child=childvec(1);
    w1=NaN;
    H1=NaN;
    T1=NaN;
    ind_vec=[ind_vec; temp child person];
end
%}
data_sim=[];
for i=1:length(ind_vec)
    child=ind_vec(i,2);
    temp=ind_vec(i,1);
    person=ind_vec(i,end);
   
    u2 = ceil(S_sim*rand(S,1));     
    person=ones(S,1)*person;
    nchild=ones(S,1)*child;
    itype=ones(S,1)*temp;
    a=hist_sim(u2,1,child, temp);
    xi=hist_sim(u2,2,child, temp);
    h_p=hist_sim(u2,3,child, temp);
    ten_p=hist_sim(u2,4,child, temp);
    w_p=hist_sim(u2,5,child, temp);
    index=hist_sim(u2,6,child, temp);
    d_p=hist_sim(u2,7,child, temp);
    w_p_true=hist_sim(u2,8,child, temp);
    u_p=hist_sim(u2,end,child,temp);
    data_sim=[data_sim; person, w_p, h_p, ten_p, a, xi, index, d_p, w_p_true, itype, nchild, u_p];
end    
%
disp('sim wages,  sim wages PT, sim wages FT')
X = [nanmean(data_sim(:,2)), mean(data_sim(data_sim(:,3)==30,2)), nanmean(data_sim(data_sim(:,3)==40,2))]; 
disp(X)
disp('No measurement errors: sim wages,  sim wages PT, sim wages FT')
X = [nanmean(data_sim(:,9)), mean(data_sim(data_sim(:,3)==30,9)), nanmean(data_sim(data_sim(:,3)==40,9)),mean(data_sim(:,end))]; 
disp(X)
disp('Hours distribution: No work, PT, FT')
table=tabulate(data_sim(:,3));
disp(table(:,end)'./100)
disp('Job tenure: PT, FT; Unemployment spell')
X = [mean(data_sim(data_sim(:,3)==30,4)), nanmean(data_sim(data_sim(:,3)==40,4)),nanmean(data_sim(data_sim(:,3)==0,8)) ]; 
disp(X)




