function [hist_sim] = sim_history(S,T, maxchild,coefs, aMat, a_off, X, u0,a_bar1, astar, a_r)

%simulate histories, starting from beginning of life
%simulate distributions of wages, types of firms, and preference over life

%**LIST OF PARAMETERS**********
h1=30;
h2=40;

v_a0=coefs(1);
lam_e=coefs(2);
p_n=coefs(3);
lam_d=coefs(4);
v_e=coefs(5); %variance of measurement error
alpha2=coefs(6);
xiMat=coefs(7:8);
p_xi2=coefs(9);
%parameters of the types; in value function since they are given
alpha1=coefs(10);  %this is the constant term (base group)
utype2=coefs(11); %utype2 relative to utype1=0
p_type2=coefs(12); %prob of second type
%wage coefs
beta=coefs(13:16)'; %constant, urate,white,metro 
%preference coefs: note there is no intercept here--we allow for two
%type-specifc intercepts 
theta=coefs(17:19)'; %white, married, children
wtype2=0;
pi= 1;
phi0=coefs(20);
lam_e2=coefs(21);
lam_d2=coefs(22);
%***************
bc=theta(end); %preference for children
xiGrids=length(xiMat);
wtype=[0; wtype2];
utype=[alpha1 alpha1+utype2];

p_xi=[1-p_xi2, p_xi2];
p_u0=[1-p_type2, p_type2];
s_a0=sqrt(v_a0);
s_e=sqrt(v_e);
%*********************************************************
aGrids=length(aMat);
X_w=[1 X(2:end)];

lw0=X_w*beta+wtype(u0);

 xi_h=xiMat(2);
 xi_l=xiMat(1);
    off = binornd(1,p_xi2,S,1);

    xi_off=ones(S,1);
    xi_type=zeros(S,1);
    for s=1:S
    if off(s)==1
        xi_off(s,1)=xi_h; %high cost
        xi_type(s,1)=2;
    elseif off(s)==0
        xi_off(s,1)=xi_l; %low cost
        xi_type(s,1)=1;
    end
    end

%simulated histories: [a_sim(:), xi_sim(:), h_sim(:), ten_sim(:), w_sim, index_sim ]    
hist_sim=zeros(S,9,maxchild+1);

for child=maxchild+1:-1:1
 
    h_off=NaN(S,1);    
    for t=1
        for s=1:S       
        xi_d = xi_type(s);
        h_off(s,1)=hour(a_off(s,t),a_bar1(xi_d, child, u0(s)), astar(xi_d, child, u0(s)), h1, h2);
        end
    end

%generate histories of accepted matches, hours and job mobility
offer_ump = binornd(1,p_n,S,1); %job arrival when unemployed with a bernouli distribution;

%initialize the process
h=zeros(S,T);    
a=NaN(S,T);  
ten=zeros(S,T); %tenure
d=zeros(S,T); %unemployment spells
xi=NaN(S,T);
for s=1:S
    if offer_ump(s,1)==0
        h(s,1)=0;
    elseif offer_ump(s,1)==1
        h(s,1)=h_off(s,1);
        if h(s,1)>0
        a(s,1)=a_off(s,1); %no match value if nonemployment
        xi(s,1)=xi_type(s,1);
        ten(s,1)=1; %tenure coded from one: make easier to identify job starting date
        d(s,1)=0;
        end
    end
end

for t=2:T
%draw acceptable a2 and determine wage and hours on the second job
    for s=1:S
        if h(s,t-1)==0 %if unemployed in last period
            offer = offer_ump(ceil(rand(1,1)*S));
            d(s,t)=d(s,t-1)+1; %count unemployment spells by t-1
            if offer==0
                h(s,t)=0;  
            elseif offer==1
                temp=ceil(rand(1,1)*S);
                xi_d = xi_type(temp); %random draw from xi_off vector
                a_d = a_off(temp); %random draw from zeta_off vector
                h(s,t)=hour(a_d, a_bar1(xi_d, child, u0(s)),  astar(xi_d, child, u0(s)), h1, h2); %expr_t-1=expr_t since last period unemployed
                if h(s,t)>0
                    a(s,t)=a_d; %no match value if nonemployment
                    xi(s,t)=xi_d;
                    ten(s,t)=1;
                end
            end
        elseif h(s,t-1)>0     %if last period was working
            d(s,t)=0; %%count unemployment spells by t-1
            if h(s,t-1)==h2
                layoff= binornd(1,lam_d2,1,1); 
                offer = binornd(1,lam_e2,1,1); %whether there is an offer
            elseif h(s,t-1)==h1
                layoff= binornd(1,lam_d,1,1);
                offer = binornd(1,lam_e,1,1); %whether there is an offer
            end
            if layoff==1
                a(s,t)=NaN;
                h(s,t)=0;
                xi(s,t)=NaN;
                ten(s,t)=0;
            elseif layoff==0
            %first predict hour, wage in the current period if continue with the current job, regardless of
            %mobility
            a(s,t)=a(s,t-1);
            xi(s,t)=xi(s,t-1);
            xi_d = xi(s,t);
            ten(s,t)=ten(s,t-1)+1;
 
            %re-calculate optimal hour with current employer: alpha could be different due to shock, expr and ten may also change hour arrangement                    
            h(s,t)=hour(a(s,t),a_bar1(xi_d, child, u0(s)),  astar(xi_d, child, u0(s)), h1, h2);  
                if offer==0 && h(s,t)==0 %if no offer and preference change resulting nonemployment
                    a(s,t)=NaN;
                    xi(s,t)=NaN;
                end
            %then consider the case when there is an external offer
                if offer==1
                    %simulate the offer
                xi_d = xi_type(ceil(rand(1,1)*S)); %random draw from zeta_off vector
                a_d = a_off(ceil(rand(1,1)*S)); %random draw from zeta_off vector
                h_d=hour(a_d, a_bar1(xi_d, child, u0(s)),  astar(xi_d, child, u0(s)), h1, h2); %optimal hour with outside firm                
                if h(s,t)>0
                    a_sim_r =interp1q(aMat,a_r(xi_d,:,xi(s,t),child,u0(s))', a(s,t));
                    if a_d>a_sim_r 
                    a(s,t)=a_d;
                    xi(s,t)=xi_d;
                    h(s,t)=h_d;
                    ten(s,t)=1; 
                    end
                elseif h(s,t)==0  %if optimal hour is nonemployment for current job (under preference change)
                    h(s,t)=h_d; %hour is equal to the optimal hours on the new job (could remain zero)                    
                    if h(s,t)==0
                        a(s,t)=NaN;
                        xi(s,t)=NaN;
                        ten(s,t)=0; %tenure is set to zero since she leaves the current firm
                    elseif h(s,t)>0
                        a(s,t)=a_d;
                        xi(s,t)=xi_d;
                        ten(s,t)=1;
                    end
                end
                end
            end
        end
    end  
end

%create an index indicating the first wage following unemployment spell
index=zeros(S,T);
for t=2:T
    for s=1:S
        if isnan(a(s,t))==0 && isnan(a(s,t-1))==1
            index(s,t)=1;
        end
    end
end

a_sim=a(:,T);
a_sim=lw0+a_sim;
xi_sim=xi(:,T);
h_sim=h(:,T);
ten_sim=ten(:,T);
d_sim=d(:,T);
index_sim=index(:,T);

    %transforming index of xi to values
    xi_v=xi_sim;
    for k=1:size(xi_sim)
        if xi_sim(k)==1
            xi_v(k)=xiMat(1);
        elseif xi_sim(k)==2
            xi_v(k)=xiMat(2);
        else
            xi_v(k)=NaN;
        end
    end

u = rand(S,1); 
error = norminv(u,0,s_e);
w_sim_true=exp(a_sim-xi_v.*(h_sim==h1));
 w_sim=exp(a_sim-xi_v.*(h_sim==h1)+error);
 
 logw_sim=log(w_sim_true);
 Z=[X(3), X(1)];
 u_sim=zeros(S,1);
 for s=1:S
    pref_pt=Z*theta(1:end-1)+utype(u0(s))+((child-1)*bc);
    u_sim(s,1)=utility(logw_sim(s,1),h_sim(s,1),h1,h2,pref_pt,alpha2,pi, phi0);
 end
 
hist_sim(:,:,child)=[a_sim, xi_sim, h_sim, ten_sim, w_sim, index_sim,d_sim,w_sim_true, u_sim];
end

return